@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -222,9 +222,10 @@ final class ReportSupport {
 						c.getName()));
 			}
 		}
-		if (bundle.getClassCounter().getTotalCount() > 0
+		if (bundle.containsCode()
 				&& bundle.getLineCounter().getTotalCount() == 0) {
-			log.warn("To enable source code annotation class files have to be compiled with debug information.");
+			log.warn(
+					"To enable source code annotation class files have to be compiled with debug information.");
 		}
 	}
 
