@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -32,6 +32,6 @@ public interface IExceptionLogger {
 	 * @param ex
 	 *            exception to log
 	 */
-	public void logExeption(Exception ex);
+	void logExeption(Exception ex);
 
 }
