@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -211,6 +211,19 @@ public class ProbeArrayStrategyFactoryTest {
 				true, 0);
 	}
 
+	@Test
+	public void testModule() {
+		final ClassWriter writer = new ClassWriter(0);
+		writer.visit(Opcodes.V9, Opcodes.ACC_MODULE, "module-info", null, null,
+				null);
+		writer.visitModule("module", 0, null).visitEnd();
+		writer.visitEnd();
+
+		final IProbeArrayStrategy strategy = ProbeArrayStrategyFactory
+				.createFor(0, new ClassReader(writer.toByteArray()), generator);
+		assertEquals(NoneProbeArrayStrategy.class, strategy.getClass());
+	}
+
 	private IProbeArrayStrategy test(int version, int access, boolean clinit,
 			boolean method, boolean abstractMethod) {
 		final ClassWriter writer = new ClassWriter(0);
@@ -241,7 +254,7 @@ public class ProbeArrayStrategyFactoryTest {
 		writer.visitEnd();
 
 		final IProbeArrayStrategy strategy = ProbeArrayStrategyFactory
-				.createFor(new ClassReader(writer.toByteArray()), generator);
+				.createFor(0, new ClassReader(writer.toByteArray()), generator);
 
 		strategy.addMembers(cv, 123);
 		return strategy;
@@ -283,7 +296,7 @@ public class ProbeArrayStrategyFactoryTest {
 		private final List<AddedMethod> methods = new ArrayList<AddedMethod>();
 
 		ClassVisitorMock() {
-			super(Opcodes.ASM5);
+			super(InstrSupport.ASM_API_VERSION);
 		}
 
 		@Override
@@ -300,7 +313,7 @@ public class ProbeArrayStrategyFactoryTest {
 				String signature, String[] exceptions) {
 			final AddedMethod m = new AddedMethod(access, name, desc);
 			methods.add(m);
-			return new MethodVisitor(Opcodes.ASM5) {
+			return new MethodVisitor(InstrSupport.ASM_API_VERSION) {
 				@Override
 				public void visitFrame(int type, int nLocal, Object[] local,
 						int nStack, Object[] stack) {
@@ -337,7 +350,8 @@ public class ProbeArrayStrategyFactoryTest {
 						assertFalse(itf);
 						return;
 					}
-					assertEquals(itf, isInterface);
+					assertEquals(Boolean.valueOf(itf),
+							Boolean.valueOf(isInterface));
 
 					assertEquals(Opcodes.INVOKESTATIC, opcode);
 					assertEquals("Foo", owner);
