@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -11,6 +11,9 @@
  *******************************************************************************/
 package org.jacoco.core.runtime;
 
+import org.junit.Assume;
+import org.junit.BeforeClass;
+
 /**
  * Unit tests for {@link URLStreamHandlerRuntime}.
  */
@@ -21,4 +24,11 @@ public class URLStreamHandlerRuntimeTest extends RuntimeTestBase {
 		return new URLStreamHandlerRuntime();
 	}
 
+	@BeforeClass
+	public static void checkJDK() {
+		final boolean jdk9 = System.getProperty("java.version")
+				.startsWith("9-");
+		Assume.assumeTrue(!jdk9);
+	}
+
 }
