@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -12,7 +12,7 @@
 package org.jacoco.core.test.validation;
 
 import static org.junit.Assert.assertEquals;
-import static org.junit.Assert.fail;
+import static org.junit.Assert.assertTrue;
 
 import java.io.IOException;
 import java.lang.reflect.Method;
@@ -22,14 +22,15 @@ import org.jacoco.core.analysis.Analyzer;
 import org.jacoco.core.analysis.CoverageBuilder;
 import org.jacoco.core.analysis.ICounter;
 import org.jacoco.core.analysis.ILine;
-import org.jacoco.core.analysis.ISourceFileCoverage;
 import org.jacoco.core.data.ExecutionData;
 import org.jacoco.core.data.ExecutionDataStore;
 import org.jacoco.core.internal.analysis.CounterImpl;
 import org.jacoco.core.test.InstrumentingLoader;
 import org.jacoco.core.test.TargetLoader;
+import org.jacoco.core.test.validation.Source.Line;
 import org.jacoco.core.test.validation.targets.Stubs;
 import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Base class for validation tests. It executes the given class under code
@@ -37,6 +38,11 @@ import org.junit.Before;
  */
 public abstract class ValidationTestBase {
 
+	protected static final boolean isJDKCompiler = Compiler.DETECT.isJDK();
+
+	protected static final JavaVersion JAVA_VERSION = new JavaVersion(
+			System.getProperty("java.version"));
+
 	private static final String[] STATUS_NAME = new String[4];
 
 	{
@@ -46,30 +52,20 @@ public abstract class ValidationTestBase {
 		STATUS_NAME[ICounter.PARTLY_COVERED] = "PARTLY_COVERED";
 	}
 
-	private final String srcFolder;
-
 	private final Class<?> target;
 
-	private ISourceFileCoverage sourceCoverage;
-
 	private Source source;
 
 	private InstrumentingLoader loader;
 
-	protected ValidationTestBase(final String srcFolder, final Class<?> target) {
-		this.srcFolder = srcFolder;
-		this.target = target;
-	}
-
 	protected ValidationTestBase(final Class<?> target) {
-		this("src", target);
+		this.target = target;
 	}
 
 	@Before
 	public void setup() throws Exception {
 		final ExecutionDataStore store = execute();
 		analyze(store);
-		source = Source.getSourceFor(srcFolder, target);
 	}
 
 	private ExecutionDataStore execute() throws Exception {
@@ -89,54 +85,106 @@ public abstract class ValidationTestBase {
 		for (ExecutionData data : store.getContents()) {
 			analyze(analyzer, data);
 		}
-
-		String srcName = target.getName().replace('.', '/') + ".java";
-		for (ISourceFileCoverage file : builder.getSourceFiles()) {
-			if (srcName.equals(file.getPackageName() + "/" + file.getName())) {
-				sourceCoverage = file;
-				return;
-			}
-		}
-		fail("No source node found for " + srcName);
+		source = Source.load(target, builder.getBundle("Test"));
 	}
 
 	private void analyze(final Analyzer analyzer, final ExecutionData data)
 			throws IOException {
-		final byte[] bytes = TargetLoader.getClassDataAsBytes(
-				target.getClassLoader(), data.getName());
+		final byte[] bytes = TargetLoader
+				.getClassDataAsBytes(target.getClassLoader(), data.getName());
 		analyzer.analyzeClass(bytes, data.getName());
 	}
 
-	protected void assertLine(final String tag, final int status) {
-		final int nr = source.getLineNumber(tag);
-		final ILine line = sourceCoverage.getLine(nr);
-		final String msg = String.format("Status in line %s: %s",
-				Integer.valueOf(nr), source.getLine(nr));
-		final int insnStatus = line.getInstructionCounter().getStatus();
-		assertEquals(msg, STATUS_NAME[status], STATUS_NAME[insnStatus]);
+	/**
+	 * All single line comments are interpreted as statements in the following
+	 * format:
+	 * 
+	 * <pre>
+	 * // statement1() statement2()
+	 * </pre>
+	 */
+	@Test
+	public void execute_assertions_in_comments() throws IOException {
+		for (Line line : source.getLines()) {
+			String exec = line.getComment();
+			if (exec != null) {
+				StatementParser.parse(exec, new StatementExecutor(this, line),
+						line.toString());
+			}
+		}
 	}
 
-	protected void assertLine(final String tag, final int missedBranches,
-			final int coveredBranches) {
-		final int nr = source.getLineNumber(tag);
-		final ILine line = sourceCoverage.getLine(nr);
-		final String msg = String.format("Branches in line %s: %s",
-				Integer.valueOf(nr), source.getLine(nr));
-		assertEquals(msg + " branches",
-				CounterImpl.getInstance(missedBranches, coveredBranches),
-				line.getBranchCounter());
+	@Test
+	public void last_line_in_coverage_data_should_be_less_or_equal_to_number_of_lines_in_source_file() {
+		assertTrue(String.format(
+				"Last line in coverage data (%d) should be less or equal to number of lines in source file (%d)",
+				Integer.valueOf(source.getCoverage().getLastLine()),
+				Integer.valueOf(source.getLines().size())),
+				source.getCoverage().getLastLine() <= source.getLines().size());
 	}
 
-	protected void assertLine(final String tag, final int status,
+	/*
+	 * Predefined assertion methods:
+	 */
+
+	private void assertCoverage(final Line line, final int insnStatus,
 			final int missedBranches, final int coveredBranches) {
-		assertLine(tag, status);
-		assertLine(tag, missedBranches, coveredBranches);
+		final ILine coverage = line.getCoverage();
+
+		String msg = String.format("Instructions (%s)", line);
+		final int actualStatus = coverage.getInstructionCounter().getStatus();
+		assertEquals(msg, STATUS_NAME[insnStatus], STATUS_NAME[actualStatus]);
+
+		msg = String.format("Branches (%s)", line);
+		assertEquals(msg,
+				CounterImpl.getInstance(missedBranches, coveredBranches),
+				coverage.getBranchCounter());
+	}
+
+	public void assertFullyCovered(final Line line, final int missedBranches,
+			final int coveredBranches) {
+		assertCoverage(line, ICounter.FULLY_COVERED, missedBranches,
+				coveredBranches);
+	}
+
+	public void assertFullyCovered(final Line line) {
+		assertFullyCovered(line, 0, 0);
+	}
+
+	public void assertPartlyCovered(final Line line, final int missedBranches,
+			final int coveredBranches) {
+		assertCoverage(line, ICounter.PARTLY_COVERED, missedBranches,
+				coveredBranches);
+	}
+
+	public void assertPartlyCovered(final Line line) {
+		assertPartlyCovered(line, 0, 0);
+	}
+
+	public void assertNotCovered(final Line line, final int missedBranches,
+			final int coveredBranches) {
+		assertCoverage(line, ICounter.NOT_COVERED, missedBranches,
+				coveredBranches);
+	}
+
+	public void assertNotCovered(final Line line) {
+		assertNotCovered(line, 0, 0);
+	}
+
+	public void assertEmpty(final Line line) {
+		assertCoverage(line, ICounter.EMPTY, 0, 0);
 	}
 
 	protected void assertLogEvents(String... events) throws Exception {
-		final Method getter = Class.forName(Stubs.class.getName(), false,
-				loader).getMethod("getLogEvents");
+		final Method getter = Class
+				.forName(Stubs.class.getName(), false, loader)
+				.getMethod("getLogEvents");
 		assertEquals("Log events", Arrays.asList(events), getter.invoke(null));
 	}
 
+	protected void assertMethodCount(final int expectedTotal) {
+		assertEquals(expectedTotal,
+				source.getCoverage().getMethodCounter().getTotalCount());
+	}
+
 }
