@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -107,6 +107,15 @@ public class Stubs {
 		throw new StubException();
 	}
 
+	/**
+	 * Throws a {@link RuntimeException} if given argument is <code>true</code>.
+	 */
+	public static void ex(boolean t) {
+		if (t) {
+			throw new StubException();
+		}
+	}
+
 	/**
 	 * Directly executes the given runnable.
 	 */
