@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -22,14 +22,14 @@ public interface ILine {
 	 * 
 	 * @return instruction counter
 	 */
-	public ICounter getInstructionCounter();
+	ICounter getInstructionCounter();
 
 	/**
 	 * Returns the branches counter for this line.
 	 * 
 	 * @return branches counter
 	 */
-	public ICounter getBranchCounter();
+	ICounter getBranchCounter();
 
 	/**
 	 * Returns the coverage status of this line, calculated from the
@@ -42,6 +42,6 @@ public interface ILine {
 	 * 
 	 * @return status of this line
 	 */
-	public int getStatus();
+	int getStatus();
 
 }
