@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -28,13 +28,13 @@ public interface IPackageCoverage extends ICoverageNode {
 	 * 
 	 * @return all classes
 	 */
-	public Collection<IClassCoverage> getClasses();
+	Collection<IClassCoverage> getClasses();
 
 	/**
 	 * Returns all source files in this package.
 	 * 
 	 * @return all source files
 	 */
-	public Collection<ISourceFileCoverage> getSourceFiles();
+	Collection<ISourceFileCoverage> getSourceFiles();
 
-}
\ No newline at end of file
+}
