@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -25,6 +25,6 @@ public interface ISessionInfoVisitor {
 	 * @param info
 	 *            session information
 	 */
-	public void visitSessionInfo(final SessionInfo info);
+	void visitSessionInfo(SessionInfo info);
 
 }
