@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -26,12 +26,12 @@ public interface IRuntime extends IExecutionDataAccessorGenerator {
 	 * @throws Exception
 	 *             any internal problem during startup
 	 */
-	public void startup(RuntimeData data) throws Exception;
+	void startup(RuntimeData data) throws Exception;
 
 	/**
 	 * Allows the coverage runtime to cleanup internals. This class should be
 	 * called when classes instrumented for this runtime are not used any more.
 	 */
-	public void shutdown();
+	void shutdown();
 
 }
