@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2009, 2016 Mountainminds GmbH & Co. KG and Contributors
+ * Copyright (c) 2009, 2019 Mountainminds GmbH & Co. KG and Contributors
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -27,6 +27,6 @@ public interface IIndexUpdate {
 	 * @param classid
 	 *            identifier of the class
 	 */
-	public void addClass(ILinkable link, long classid);
+	void addClass(ILinkable link, long classid);
 
 }
